from textwrap import dedent

ENV_FILE_CONTENT = dedent("""
# Project
TITLE="{title}"
DESCRIPTION="{description}"
VERSION="{version}"

# Debugging
DEBUG=True

# Server
PORT=8000
HOST="0.0.0.0"

# Database
DB_USER=""
DB_PASS=""
DB_HOST=""
DB_PORT=
DB_NAME=""
DB_TYPE=""
""")



from builders_hut.setups import BaseSetup
from typing import Literal
from builders_hut.setups.database import DatabaseFactory


class SetupDatabase(BaseSetup):
    """setup database"""

    def create(self):
        DatabaseFactory(self.database_provider, self.location).setup_db()

    def configure(
        self,
        database_type: Literal["sql", "nosql"],
    ):
        self.database_type = database_type
